==> kubernetes-model-1.0.46-sources.jar: io/fabric8/openshift/api/model/GitBuildSourceBuilder.java <==
package io.fabric8.openshift.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.HashMap;
import java.io.Serializable;
import java.util.Map;
import java.util.Map;
import java.util.AbstractMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.BaseFluent;

public class GitBuildSourceBuilder extends GitBuildSourceFluentImpl<GitBuildSourceBuilder> implements VisitableBuilder<GitBuildSource,GitBuildSourceBuilder>{

     GitBuildSourceFluent<?> fluent;
public GitBuildSourceBuilder(){
    this(new GitBuildSource());
}
public GitBuildSourceBuilder( GitBuildSourceFluent<?> fluent ){
    this(fluent, new GitBuildSource());
}
public GitBuildSourceBuilder( GitBuildSourceFluent<?> fluent , GitBuildSource instance ){
    this.fluent = fluent; fluent.withHttpProxy(instance.getHttpProxy()); fluent.withHttpsProxy(instance.getHttpsProxy()); fluent.withRef(instance.getRef()); fluent.withUri(instance.getUri()); 
}
public GitBuildSourceBuilder( GitBuildSource instance ){
    this.fluent = this; this.withHttpProxy(instance.getHttpProxy()); this.withHttpsProxy(instance.getHttpsProxy()); this.withRef(instance.getRef()); this.withUri(instance.getUri()); 
}

public EditableGitBuildSource build(){
    EditableGitBuildSource buildable = new EditableGitBuildSource(fluent.getHttpProxy(),fluent.getHttpsProxy(),fluent.getRef(),fluent.getUri());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
GitBuildSourceBuilder that = (GitBuildSourceBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}

==> kubernetes-model-1.0.50-sources.jar: io/fabric8/openshift/api/model/GitBuildSourceBuilder.java <==
package io.fabric8.openshift.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.HashMap;
import java.io.Serializable;
import java.util.Map;
import java.util.Map;
import java.util.AbstractMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Visitable;

public class GitBuildSourceBuilder extends GitBuildSourceFluentImpl<GitBuildSourceBuilder> implements VisitableBuilder<GitBuildSource,GitBuildSourceBuilder>{

     GitBuildSourceFluent<?> fluent;
public GitBuildSourceBuilder(){
    this(new GitBuildSource());
}
public GitBuildSourceBuilder( GitBuildSourceFluent<?> fluent ){
    this(fluent, new GitBuildSource());
}
public GitBuildSourceBuilder( GitBuildSourceFluent<?> fluent , GitBuildSource instance ){
    this.fluent = fluent; fluent.withHttpProxy(instance.getHttpProxy()); fluent.withHttpsProxy(instance.getHttpsProxy()); fluent.withRef(instance.getRef()); fluent.withUri(instance.getUri()); 
}
public GitBuildSourceBuilder( GitBuildSource instance ){
    this.fluent = this; this.withHttpProxy(instance.getHttpProxy()); this.withHttpsProxy(instance.getHttpsProxy()); this.withRef(instance.getRef()); this.withUri(instance.getUri()); 
}

public GitBuildSource build(){
    GitBuildSource buildable = new GitBuildSource(fluent.getHttpProxy(),fluent.getHttpsProxy(),fluent.getRef(),fluent.getUri());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
GitBuildSourceBuilder that = (GitBuildSourceBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    Validator validator = null;
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        validator = factory.getValidator();
    } catch(ValidationException e) {
        //ignore
        return;
    }

    Set<ConstraintViolation<T>> violations = validator.validate(item);
    if (!violations.isEmpty()) {
        throw new ConstraintViolationException(violations);
    }
}

}
